# New in 0.10.1 (2021-05-04)

## Changes

-   Includes new optional variance parameterization for the `Encoder` module ([#1037]).
-   Provides new way to select subpopulations for DE using Pandas queries ([#1041]).
-   Update reference to peakVI ([#1046]).
-   Pin Pytorch Lightning version to \<1.3

## Contributors

-   [@adamgayoso]
-   [@PierreBoyeau]
-   [@talashuach]

[#1037]: https://github.com/YosefLab/scvi-tools/pull/1037
[#1041]: https://github.com/YosefLab/scvi-tools/pull/1041
[#1046]: https://github.com/YosefLab/scvi-tools/pull/1046
[@adamgayoso]: https://github.com/adamgayoso
[@pierreboyeau]: https://github.com/PierreBoyeau
[@talashuach]: https://github.com/talashuach
